@@ -1,5 +1,5 @@
 package Test::WWW::Mechanize::Mojo;
-
+$Test::WWW::Mechanize::Mojo::VERSION = '0.0.18';
 use strict;
 use warnings;
 
@@ -13,8 +13,6 @@ use base 'Test::WWW::Mechanize';
 
 use Test::Mojo;
 
-our $VERSION = '0.0.17';
-
 our $APP_CLASS;
 my $Test = Test::Builder->new();
 
@@ -29,7 +27,7 @@ sub has_mojo_app
 {
     my $self = shift;
 
-    return exists($self->{mojo_app});
+    return exists( $self->{mojo_app} );
 }
 
 sub allow_external
@@ -60,7 +58,7 @@ sub clear_host
 {
     my $self = shift;
 
-    delete($self->{host});
+    delete( $self->{host} );
 
     return;
 }
@@ -69,10 +67,9 @@ sub has_host
 {
     my $self = shift;
 
-    return exists($self->{host});
+    return exists( $self->{host} );
 }
 
-
 sub tester
 {
     my $self = shift;
@@ -85,35 +82,37 @@ sub tester
     return $self->{tester};
 }
 
-sub new {
-  my $class = shift;
+sub new
+{
+    my $class = shift;
 
-  my $args = ref $_[0] ? $_[0] : { @_ };
+    my $args = ref $_[0] ? $_[0] : {@_};
 
-  my $tester = delete($args->{tester});
+    my $tester = delete( $args->{tester} );
 
-  my $self = $class->SUPER::new(%$args);
+    my $self = $class->SUPER::new(%$args);
 
-  if ($tester)
-  {
-      $self->tester($tester);
-  }
-  else
-  {
-      $self->tester(Test::Mojo->new());
-  }
+    if ($tester)
+    {
+        $self->tester($tester);
+    }
+    else
+    {
+        $self->tester( Test::Mojo->new() );
+    }
 
-  $self->{allow_external} = 0;
+    $self->{allow_external} = 0;
 
-  return $self;
+    return $self;
 }
 
-sub _make_request {
+sub _make_request
+{
     my ( $self, $request ) = @_;
 
     my $response = $self->_do_mojo_request($request);
     $response->header( 'Content-Base', $response->request->uri )
-      unless $response->header('Content-Base');
+        unless $response->header('Content-Base');
 
     $self->cookie_jar->extract_cookies($response) if $self->cookie_jar;
 
@@ -122,8 +121,8 @@ sub _make_request {
         && $response->code == 500
         && $response->content =~ /on Catalyst \d+\.\d+/ )
     {
-        my ($error)
-            = ( $response->content =~ /<code class="error">(.*?)<\/code>/s );
+        my ($error) =
+            ( $response->content =~ /<code class="error">(.*?)<\/code>/s );
         $error ||= "unknown error";
         decode_entities($error);
         $Test->diag("Catalyst error screen: $error");
@@ -156,18 +155,21 @@ sub _make_request {
             $end_of_chain = $end_of_chain->previous;
         }                                          #   of the chain...
         $end_of_chain->previous($old_response);    # ...and add us to it
-    } else {
+    }
+    else
+    {
         $response->{_raw_content} = $response->content;
     }
 
     return $response;
 }
 
-sub _do_mojo_request {
-    my ($self, $request) = @_;
+sub _do_mojo_request
+{
+    my ( $self, $request ) = @_;
 
     my $uri = $request->uri;
-    $uri->scheme('http') unless defined $uri->scheme;
+    $uri->scheme('http')    unless defined $uri->scheme;
     $uri->host('localhost') unless defined $uri->host;
 
     $request = $self->prepare_request($request);
@@ -175,48 +177,44 @@ sub _do_mojo_request {
 
     # Woe betide anyone who unsets MOJO_SERVER
     return $self->_do_remote_request($request)
-      if $ENV{MOJO_SERVER};
+        if $ENV{MOJO_SERVER};
 
     # If there's no Host header, set one.
-    unless ($request->header('Host')) {
-      my $host = $self->has_host
-               ? $self->host
-               : $uri->host;
+    unless ( $request->header('Host') )
+    {
+        my $host =
+              $self->has_host
+            ? $self->host
+            : $uri->host;
 
-      $request->header('Host', $host);
+        $request->header( 'Host', $host );
     }
 
     my $res = $self->_check_external_request($request);
     return $res if $res;
 
     my @creds = $self->get_basic_credentials( "Basic", $uri );
-    $request->authorization_basic( @creds ) if @creds;
+    $request->authorization_basic(@creds) if @creds;
 
     my $t = $self->tester;
 
     # Client
     my $client = $t->ua;
-    $client->server->app($t->app);
+    $client->server->app( $t->app );
 
-    my $method = lc($request->method());
+    my $method = lc( $request->method() );
 
     my %headers =
-    (
-        map { $_ => $request->header($_) }
-        $request->header_field_names()
-    );
+        ( map { $_ => $request->header($_) } $request->header_field_names() );
 
-    my $mojo_res = $client->$method($uri->path_query(),
-        { %headers },
-        $request->content,
-    )->res;
+    my $mojo_res =
+        $client->$method( $uri->path_query(), {%headers}, $request->content, )
+        ->res;
 
-    my $response = HTTP::Response->new(
-        $mojo_res->code(),
-        $mojo_res->message(),
-        [ %{$mojo_res->headers->to_hash()} ],
-        $mojo_res->body()
-    );
+    my $response =
+        HTTP::Response->new( $mojo_res->code(), $mojo_res->message(),
+        [ %{ $mojo_res->headers->to_hash() } ],
+        $mojo_res->body() );
 
     # LWP would normally do this, but we dont get down that far.
     $response->request($request);
@@ -224,27 +222,31 @@ sub _do_mojo_request {
     return $response;
 }
 
-sub _check_external_request {
-    my ($self, $request) = @_;
+sub _check_external_request
+{
+    my ( $self, $request ) = @_;
 
     # If there's no host then definatley not an external request.
     $request->uri->can('host_port') or return;
 
-    if ( $self->allow_external && $request->uri->host_port ne 'localhost:80' ) {
+    if ( $self->allow_external && $request->uri->host_port ne 'localhost:80' )
+    {
         return $self->SUPER::_make_request($request);
     }
     return undef;
 }
 
-sub _do_remote_request {
-    my ($self, $request) = @_;
+sub _do_remote_request
+{
+    my ( $self, $request ) = @_;
 
     my $res = $self->_check_external_request($request);
     return $res if $res;
 
-    my $server  = URI->new( $ENV{MOJO_SERVER} );
+    my $server = URI->new( $ENV{MOJO_SERVER} );
 
-    if ( $server->path =~ m|^(.+)?/$| ) {
+    if ( $server->path =~ m|^(.+)?/$| )
+    {
         my $path = $1;
         $server->path("$path") if $path;    # need to be quoted
     }
@@ -252,22 +254,27 @@ sub _do_remote_request {
     # the request path needs to be sanitised if $server is using a
     # non-root path due to potential overlap between request path and
     # response path.
-    if ($server->path) {
+    if ( $server->path )
+    {
         # If request path is '/', we have to add a trailing slash to the
         # final request URI
         my $add_trailing = $request->uri->path eq '/';
 
         my @sp = split '/', $server->path;
         my @rp = split '/', $request->uri->path;
-        shift @sp;shift @rp; # leading /
-        if (@rp) {
-            foreach my $sp (@sp) {
-                $sp eq $rp[0] ? shift @rp : last
+        shift @sp;
+        shift @rp;    # leading /
+        if (@rp)
+        {
+            foreach my $sp (@sp)
+            {
+                $sp eq $rp[0] ? shift @rp : last;
             }
         }
-        $request->uri->path(join '/', @rp);
+        $request->uri->path( join '/', @rp );
 
-        if ( $add_trailing ) {
+        if ($add_trailing)
+        {
             $request->uri->path( $request->uri->path . '/' );
         }
     }
@@ -283,10 +290,18 @@ sub _do_remote_request {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Test::WWW::Mechanize::Mojo - Test::WWW::Mechanize for Mojo / Mojolicious
 
+=head1 VERSION
+
+version 0.0.18
+
 =head1 SYNOPSIS
 
   # We're in a t/*.t test script...
@@ -372,6 +387,10 @@ please use:
 
 An alternative to this module is L<Test::Mojo>.
 
+=head1 VERSION
+
+version 0.0.18
+
 =head1 CONSTRUCTOR
 
 =head2 new
@@ -583,7 +602,6 @@ One workaround for this is that if you are expecting to redirect to an external
 site, clone the TWMC obeject and use the cloned object for the external
 redirect.
 
-
 =head1 SEE ALSO
 
 Related modules which may be of interest: L<Mojo>,
@@ -610,4 +628,131 @@ Copyright (C) 2005-8, Leon Brocard
 This module is free software; you can redistribute it or modify it
 under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2005 by Leon Brocard.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/test-www-mechanize-mojo/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc Test::WWW::Mechanize::Mojo
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/Test-WWW-Mechanize-Mojo>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/Test-WWW-Mechanize-Mojo>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-WWW-Mechanize-Mojo>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/Test-WWW-Mechanize-Mojo>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Test-WWW-Mechanize-Mojo>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/Test-WWW-Mechanize-Mojo>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/T/Test-WWW-Mechanize-Mojo>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Test-WWW-Mechanize-Mojo>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Test::WWW::Mechanize::Mojo>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-test-www-mechanize-mojo at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Test-WWW-Mechanize-Mojo>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/test-www-mechanize-mojo>
+
+  git clone git://github.com/shlomif/test-www-mechanize-mojo.git
+
 =cut
