@@ -18,23 +18,26 @@ Catty->config(
 Catty->setup();
 Catty->log->levels("fatal");
 
-sub default : Private {
+sub default : Private
+{
     my ( $self, $context ) = @_;
     my $html = html( "Root", "This is the root page" );
     $context->response->content_type("text/html");
     $context->response->output($html);
 }
 
-sub hello : Global {
+sub hello : Global
+{
     my ( $self, $context ) = @_;
-    my $str = Encode::encode('utf-8', "\x{263A}"); # ☺
+    my $str = Encode::encode( 'utf-8', "\x{263A}" );    # ☺
     my $html = html( "Hello", "Hi there! $str" );
     $context->response->content_type("text/html; charset=utf-8");
     $context->response->output($html);
 }
 
 # absolute redirect
-sub hi : Global {
+sub hi : Global
+{
     my ( $self, $context ) = @_;
     my $where = $context->uri_for('hello');
     $context->response->redirect($where);
@@ -42,33 +45,39 @@ sub hi : Global {
 }
 
 # partial (relative) redirect
-sub greetings : Global {
+sub greetings : Global
+{
     my ( $self, $context ) = @_;
     $context->response->redirect("hello");
     return;
 }
 
 # redirect to a redirect
-sub bonjour : Global {
+sub bonjour : Global
+{
     my ( $self, $context ) = @_;
     my $where = $context->uri_for('hi');
     $context->response->redirect($where);
     return;
 }
 
-sub check_auth_basic : Global {
+sub check_auth_basic : Global
+{
     my ( $self, $context ) = @_;
 
     my $auth = $context->req->headers->authorization;
     ($auth) = $auth =~ /Basic\s(.*)/i;
     $auth = decode_base64($auth);
 
-    if ( $auth eq "user:pass" ) {
+    if ( $auth eq "user:pass" )
+    {
         my $html = html( "Auth", "This is the auth page" );
         $context->response->content_type("text/html");
         $context->response->output($html);
         return $context;
-    } else {
+    }
+    else
+    {
         my $html = html( "Auth", "Auth Failed!" );
         $context->response->content_type("text/html");
         $context->response->output($html);
@@ -77,14 +86,16 @@ sub check_auth_basic : Global {
     }
 }
 
-sub redirect_with_500 : Global {
+sub redirect_with_500 : Global
+{
     my ( $self, $c ) = @_;
     $DB::single = 1;
-    $c->res->redirect( $c->uri_for("/bonjour"));
+    $c->res->redirect( $c->uri_for("/bonjour") );
     die "erk!";
 }
 
-sub die : Global {
+sub die : Global
+{
     my ( $self, $context ) = @_;
     my $html = html( "Die", "This is the die page" );
     $context->response->content_type("text/html");
@@ -92,16 +103,18 @@ sub die : Global {
     die "erk!";
 }
 
-sub name : Global {
-    my ($self, $c) = @_;
+sub name : Global
+{
+    my ( $self, $c ) = @_;
 
     my $html = html( $c->config->{name}, "This is the die page" );
     $c->response->content_type("text/html");
     $c->response->output($html);
 }
 
-sub host : Global {
-    my ($self, $c) = @_;
+sub host : Global
+{
+    my ( $self, $c ) = @_;
 
     my $host = $c->req->header('Host') || "<undef>";
     my $html = html( $c->config->{name}, "Host: $host" );
@@ -109,7 +122,8 @@ sub host : Global {
     $c->response->output($html);
 }
 
-sub html {
+sub html
+{
     my ( $title, $body ) = @_;
     return qq{
 <html>
@@ -121,11 +135,12 @@ $body
 };
 }
 
-sub gzipped : Global {
+sub gzipped : Global
+{
     my ( $self, $c ) = @_;
 
-  # If done properly this test should check the accept-encoding header, but we
-  # control both ends, so just always gzip the response.
+    # If done properly this test should check the accept-encoding header, but we
+    # control both ends, so just always gzip the response.
     require Compress::Zlib;
 
     my $html = html( "Hello", "Hi there! ☺" );
@@ -135,12 +150,13 @@ sub gzipped : Global {
     $c->response->headers->push_header( 'Vary', 'Accept-Encoding' );
 }
 
-sub user_agent : Global {
+sub user_agent : Global
+{
     my ( $self, $c ) = @_;
 
-    my $html = html($c->req->user_agent, $c->req->user_agent);
+    my $html = html( $c->req->user_agent, $c->req->user_agent );
     $c->response->content_type("text/html; charset=utf-8");
-    $c->response->output( $html );
+    $c->response->output($html);
 
 }
 
